MINOR: mux-h2: add a new dummy stream for the REFUSED_STREAM error code

This patch introduces a new dummy stream, h2_refused_stream, in CLOSED
status with the aforementioned error code. It will be usable to reject
unexpected extraneous streams.
diff --git a/src/mux_h2.c b/src/mux_h2.c
index 02890e0..b319d47 100644
--- a/src/mux_h2.c
+++ b/src/mux_h2.c
@@ -29,8 +29,9 @@
 #include <eb32tree.h>
 
 
 /* dummy streams returned for idle and closed states */
 static const struct h2s *h2_closed_stream;
+static const struct h2s *h2_refused_stream;
 static const struct h2s *h2_idle_stream;
 
 /* Connection flags (32 bit), in h2c->flags */
@@ -229,6 +230,16 @@
 	.id        = 0,
 };
 
+/* a dmumy closed stream returning a REFUSED_STREAM error */
+static const struct h2s *h2_refused_stream = &(const struct h2s){
+	.cs        = NULL,
+	.h2c       = NULL,
+	.st        = H2_SS_CLOSED,
+	.errcode   = H2_ERR_REFUSED_STREAM,
+	.flags     = 0,
+	.id        = 0,
+};
+
 /* and a dummy idle stream for use with any unannounced stream */
 static const struct h2s *h2_idle_stream = &(const struct h2s){
 	.cs        = NULL,
@@ -29,8 +29,9 @@
 
 
-/* dummy streams returned for idle and closed states */
+/* dummy streams returned for closed, refused, idle and states */
 static const struct h2s *h2_closed_stream;